moe_Idiom = ["一日到暗","一半日仔","人情世事","三心兩意","上卌袂攝","山伯英台","三除四扣","大富大貴","不敢當","天反地亂","月外日","毋甘嫌","毋甘願","毋成人","毋成樣","心狂火著","反來反去","毋知死","歹剃頭","毋是勢","反倒轉","毋情願","夭壽短命","心驚膽嚇","仙拚仙","仝爸各母","央三託四","卯死矣","去傷解鬱","加講話","平","正當時","用","在欉黃","好好人","如此如此","好育飼","尖跤幼手","有一無兩","死人款","有耳無喙","死坐活食","有的無的","有空無榫","有要緊","有時有陣","收跤洗手","死路旁","死賴人","百百空","自作孽","行後尾門","吵家抐宅","吵家抐計","刣雞教猴","弄狗相咬","求神問佛","走袂開跤","走袂離","走赦馬","佯毋知","佯顛佯戇","卸世眾","初見面","卸祖公","受袂起","卸責任","受當袂起","姑換嫂","孤𣮈絕種","孤毛絕種","拖身拖命","拖屎連","拆食落腹","放粉鳥","拍通關","拚暝工","抽豬母稅","東倒西歪","爸老囝幼","花袂牢枝","青面獠牙","迎新棄舊","近廟欺神","青磅白磅","促歲壽","哀爸叫母","哎喲喂","度小月","幽幽仔疼","挖心肝","是按怎","枵飽吵","洗門風","流豬哥瀾","相交插","相卸代","相挨相𤲍","紅膏赤蠘","若有若無","重敧爿","食外口","食便領現","食清領便","食軟驚硬","食膨餅","食頭路","風聲嗙影","哭爸哭母","唔唔睏","崁頭崁面","料想袂到","氣身惱命","烏白來","消災解厄","消瘦落肉","烏魯木齊","笑頭笑面","袂收山","袂按算","袂食袂睏","袂得過","袂輸講","袂講得","袂伸捙","起毛䆀","起毛婸","起跤動手","起藥蛆","釘孤枝","鬥做伙","假仙假觸","假好衰","假死假活","偷來暗去","偷咬雞仔","假鬼假怪","娶新婦","惜命命","徛衛兵","捽目尾","掠交替","掠沙筋","掠兔仔","掠坦橫","掠長補短","掠無頭摠","掠龜走鱉","欲死欲活","欲呢","添福壽","粗菜便飯","軟塗深掘","陳三五娘","善男信女","啼啼哭哭","割稻仔尾","插一跤","插喙插舌","敢毋是","敢有","無一定","無了時","無大無細","無天理","無代無誌","無打緊","無良心","無事使","無依無倚","無奈","無奈何","無所謂","無法伊","無法度","無法無天","無某無猴","無要無緊","無要緊","無啥物","無啥貨","無意無思","無暝無日","無影無跡","無錯","無聲無說","無講無呾","無礙著","痠抽疼","硬拄硬","著賊偷","趁流水","費氣費觸","傳後嗣","傷風敗俗","傷腦筋","幌韆鞦","想東想西","想空想縫","搧大耳","搵豆油","搦屎搦尿","搝搝搦搦","楔手縫","照步來","照呼照行","當頭白日","當頭對面","落人的喙","舅仔探房","腹肚枵","落空逝","試看覓","裝痟的","跤尖手幼","跤來手來","趒跤頓蹄","較快","飼查某","頓椅頓桌","嘛是","僫做","嘛欲","嘈嘈滴","僫講","慢行","慢慢仔是","摸無路","滿四界","滲屎尿","滿滿是","漲懸價","管待伊","算袂和","算無盤","綴人走","綿死綿爛","緊事寬辦","綴前綴後","鉸刀爿","屧手縫","寬寬仔是","憂頭結面","霆水螺","噪人耳","激怐怐","瞞天過海","糖甘蜜甜","膨肚短命","謀財害命","隨在你","頭眩目暗","聲聲句句","講大聲話","軁錢空","轉彎踅角","雙面刀鬼","癩𰣻爛癆","纏跤絆手","鐵骨仔生","鐵齒銅牙槽","顧人怨","顧三頓","彎來斡去","觀前顧後","𠢕吮食","𬦰懸𬦰低","勼跤勼手","反起反倒","手梳攑懸","水崩山","王見王","含血霧天","厚操煩","重本","食好料","捎無摠","疼命命","啉酒醉","通人知","喝起喝倒","無天良","無捨施","無盤","會記得","跤麻手痺","實䈄","算會和","頭轉客","離跤手","一必一中","人懸漢大","大人大種","大目孔","大身大命","大嚨喉空","天公地道","心狂火熱","心花開","心慒慒","手爪賤","手面趁食","手縫櫳","月圍箍","歹面相看","歹紡","牛聲馬喉","半老老","司公仔象桮","生頭凊面","交落身","好死毋死","好唯是","有路無厝","行袂開跤","忘恩背義","辛苦病疼","卸世卸眾","孤跤手","侵門踏戶","南北二路","挑花刺繡","枵飢失頓","枵過飢","流汗流洘","為非糝做","看破跤手","看袂上目","面漚面臭","食人夠夠","食老出癖","食重鹹","食銅食鐵","挽瓜揫藤","梳妝打扮","氣暢忍","袂做得","袂博假博","袂曉衰","起酒痟","起蛟龍","迵海","夠月","惜花連盆","牽龜落湳","笨跤笨手","規碗捀","規嚾規黨","頂下歲","博士博","喙笑目笑","報鳥鼠仔冤","惡人無膽","欺貧重富","無才","硩番薯","順行","搝後跤","搭胸坎","會得過","準拄煞","腰痠背疼","萬丈深坑","倚山食山","挨挨陣陣","漚戲拖棚","趖跤趖手","閬雨縫","燖補","縛跤縛手","親疊親","無底代","頭較大身","戴小鬼仔殼","臨時臨曜","鏨頭短命","鹹酸苦汫","攑香綴拜","灇水","變工藝","變啥魍","金言玉語","好食睏","大趁錢","落空車","規山坪","海水倒激"]