DT_Idiom = ["痟狗舂墓壙",
            "船過水無痕",
            "毛呼龜粿粽",
            "識皮包戇餡",
            "過五關斬六將",
            "過五關",
            "斬六將"
            "一刀兩斷",
            "倚海食海",
            "禽獸不如",
            "花天酒地",
            "風調雨順",
            "毋知死活",
            "青盲精",
            "啞口靈",
            "大尊大",
            "細尊細",
            "洞房花燭夜",
            "金榜題名時",
            "三分天註定",
            "七分靠拍拚",
            "胭脂馬拄著關老爺",
            "由淺入深",
            "光天化日",
            "家財萬貫",
            "見講見對",
            "一仙五厘",
            "來者是客",
            "一工到暗",
            "談情說愛",
            "馬耳東風",
            "滿面春風",
            "相親相愛",
            "輕聲細說",
            "春風滿面",
            "有頭有尾",
            "偷工減料",
            "雙跤踏雙船",
            "虎頭鳥鼠尾",
            "食好鬥相報",
            "無三日的好光景",
            "無三日好光景"
            ]