DT_Modifier = ["無細膩",
               "差不多",
               "自然",
               "主要",
               "一定",
               "一般",
               "一併",
               "一同",
               "一致",
               "一身",
               "一共",
               "細條",
               "大條",
               "大圈",
               "無論",
               "無局",
               "營養",
               "合理",
               "揜貼",
               "牢牢",
               "親身",
               "焦鬆",
               "勇敢",
               "慎重",
               "真濟",
               "真湳",
               "真仁",
               "要緊",
               "凡勢",
               "真普遍",
               "普遍",
               "富",
               "誠濟",
               "驚人",
               "忘恩背義",
               "鐵骨仔生",
               "尖跤幼手",
               "挨挨陣陣",
               "若有若無",
               "在欉黃",
               "活跳跳",
               "插插插",
               "無盤",
               "上好",
               "主動",
               "圇圇",
               "蠻皮",
               "安靜",
               "滾滾",
               "昭昭",
               "原本",
               "原來",
               "足吵",
               "足遠",
               "足足",
               "公立",
               "私立",
               "國立",
               "才閣",
               "斷掌",
               "離譜",
               "烏白",
               "黑白",
               "粗魯",
               "複雜",
               "較早",
               "較晏",
               "較芳",
               "水水",
               "的確",
               "明顯",
               "好空",
               "好命",
               "好運",
               "好看",
               "好聽",
               "好食",
               "好抱",
               "好命底",
               "好禮仔",
               "好唯是",
               "好聲說",
               "歹命",
               "歹食",
               "歹運",
               "歹吉兆",
               "迫促",
               "出在",
               "文雅",
               "較委屈",
               "誠長",
               "長途",
               "長期",
               "短期",
               "短站",
               "短命",
               "條直",
               "精密",
               "殘忍",
               "透透",
               "夠水",
               "夠月",
               "特別",
               "大概",
               "大細聲",
               "軟㽎㽎",
               "金爍爍",
               "欲倒欲倒",
               "大空細裂",
               "對同仔對同",
               "現現",
               "平平",
               "生生",
               "恬恬",
               "有效",
               "無效",
               "有穿",
               "有閒",
               "有閒工",
               "總是",
               "做伙",
               "困難",
               "艱難",
               "夭壽",
               "激烈",
               "寶貴",
               "開闊",
               "正經",
               "正當",
               "清廉",
               "清楚",
               "輕便",
               "嘛欲",
               "少年",
               "困苦",
               "值錢",
               "野味",
               "奸巧",
               "細膩",
               "絕對",
               "實在",
               "爾爾",
               "歹空",
               "真正",
               "用得",
               "適合",
               "寒酸",
               "可惡",
               "可愛",
               "巷仔內的",
               "凊凊彩彩",
               "甘甜",
               "半精白",
               "總共",
               "貴重",
               "詼諧",
               "真花",
               "真害",
               "該然",
               "早期",
               "中期",
               "晚期",
               "誠皮",
               "獨裁",
               "獨身",
               "白目",
               "臭耳",
               "久長",
               "久久長長",
               "無要緊",
               "相連紲",
               "無才",
               "誠懸",
               "奇怪",
               "小心",
               "孤單",
               "孤獨",
               "厲害",
               "老練",
               "直直",
               "直溜溜",
               "公平",
               "嚴重",
               "簡單",
               "當然",
               "散赤",
               "䆀猴",
               "誠懇",
               "砧砧",
               "爽快",
               "穩心仔",
               "開明",
               "吉祥",
               "如意",
               "平安",
               "充分",
               "專業",
               "公共",
               "完整",
               "實施",
               "小可",
               "急性",
               "提早",
               "撥開",
               "撫養",
               "大漢",
               "播出",
               "擔憂",
               "改薰",
               "改革",
               "新亡",
               "神奇",
               "耐用",
               "貧窮",
               "首輪",
               "齊全",
               "慢性",
               "急性",
               "凍霜",
               "自由",
               "安全",
               "安定",
               "偏偏",
               "方便",
               "大方",
               "一品",
               "二品",
               "劇烈",
               "死鹹",
               "整齊",
               "空空",
               "人造",
               "規擔",
               "譀古",
               "具體",
               "真靈",
               "閃閃",
               "連續",
               "精彩",
               "二來",
               "無奈",
               "憂頭結面",
               "簡簡單單",
               "糜糜卯卯",
               "情投意合",
               "鬚聳目降",
               "金光閃閃",
               "閃閃爍爍",
               "瑞氣千條",
               "有家有後",
               "老神在在",
               "馬西馬西",
               "當頭對面",
               "一勻塗",
               "不得了",
               "無仝款",
               "無好尾",
               "無聊",
               "袂赴",
               "快活",
               "垃儳",
               "大箍",
               "富裕",
               "危險",
               "確實",
               "下痟",
               "代先",
               "辛苦",
               "黏黏",
               "去去倒倒",
               "滿四界",
               "走第一",
               "好育飼",
               "害害去",
               "強強欲",
               "實捅捅",
               "博士博",
               "博",
               "現",
               "奅",
               "炎",
               "狂",
               "雄",
               "疏",
               "細",
               "暗",
               "疏遠",
               "直接",
               "互相",
               "博學",
               "根本",
               "強欲",
               "清涼",
               "好用",
               "大力",
               "小力",
               "緊性",
               "惡",
               "寒",
               "久",
               "醉",
               "猶",
               "野",
               "先",
               "拄拄",
               "拄好",
               "拄拄好",
               "袂拄好",
               "硬迸迸",
               "磕袂著",
               "手爪賤",
               "歹心行",
               "一箍槌槌",
               "猴猴",
               "有通",
               "正範",
               "私奇",
               "輾轉",
               "仝班",
               "正常",
               "正面",
               "負面",
               "復古",
               "十足",
               "較快",
               "較慢",
               "較清",
               "較清彩",
               "較明",
               "較開",
               "楦大",
               "老罔老",
               "無天良",
               "無良心",
               "無天理",
               "甜粅粅",
               "花花",
               "苦苦",
               "自排",
               "自願",
               "雙重",
               "夠力",
               "衰洨",
               "衰小",
               "赤跤",
               "大粒",
               "爛爛",
               "拄搪",
               "大約",
               "豪爽",
               "果然",
               "較清心",
               "高速",
               "慢速",
               "惡質",
               "並濟",
               "不仁",
               "熟手",
               "萬無一失",
               "清心",
               "多多",
               "快樂",
               "高級",
               "有時",
               "違法",
               "皺皺",
               "較準",
               "興興",
               "較低級",
               "自私",
               "正當時",
               "平等",
               "厚重",
               "明明",
               "純天然",
               "天然",
               "彎來斡去",
               "末趁",
               "好趁",
               "重",
               "上鮮",
               "較重",
               "善良",
               "心慒慒",
               "鬼鬼祟祟",
               "醬醬醬",
               "反常",
               "順利",
               "長進",
               "天生",
               "重鹹",
               "重要",
               "重大",
               "樸實",
               "死酸",
               "活潑",
               "嚴格",
               "便利",
               "中立",
               "中央",
               "希罕",
               "透流",
               "詳細",
               "較倚",
               "較貴",
               "努力",
               "豐富",
               "食賰",
               "殕殕",
               "細枝",
               "真甘",
               "老實",
               "就近",
               "正港",
               "內行",
               "細跤",
               "臭香",
               "臭老",
               "七少年八少年",
               "放心仔",
               "通人知",
               "豬狗牛",
               "好份",
               "平歲",
               "平懸",
               "平安",
               "烏鉎",
               "親手",
               "怪怪",
               "客氣",
               "堅定",
               "傷重",
               "到尾",
               "相關",
               "二手",
               "準時",
               "蓋懸",
               "尾仔",
               "親目",
               "過份",
               "牢",
               "涼",
               "滿",
               "大",
               "圓",
               "直",
               "𠕇",
               "一等一",
               "無捨施",
               "袂講得",
               "無底代",
               "無礙著",
               "飛飛",
               "冗",
               "滇",
               "老",
               "幼",
               "齪",
               "怙",
               "散",
               "好",
               "肥",
               "假",
               "歹",
               "苛",
               "愈",
               "素",
               "賰",
               "煞",
               "奇",
               "平",
               "小",
               "iap-thiap",
               "chē",
               "順sòa",
               "kāng款",
               "kau-penn", "kau-pinn", "ji̍p-ní", "li̍p-ní", "kim-siak-siak", "pe̍h-tsiánn-bô-bī", "pîng-kin", "pîng-kun", "nā-sī", "sí-ba̍k", "guā-nī", "tông-sî", "lio̍h-lio̍h-á", "tsiòng-tsâi", "bián siàu-siūnn", "bū-bū", "thàu-àm", "pháinn-khuànn-bīn", "phái-khuànn-bīn", "kui-bué", "kui-bé", "tuā-ba̍k-khóng", "tú-tshiāng", "ē-tit-thang", "ngia̍uh-ngia̍uh-sô", "ka-tsài", "tāi-liōng", "ha̍p-sǹg", "pn̄g-tháng", "tuā-pah", "nńg-sim", "pah-bīn", "piān-piān", "tsi̍t-khùn-á", "kong-ka", "ē-tit", "bān-tshiánn-sī", "ū-kàu", "tiau-kòo-ì", "iù-siù", "bô-tú-hó", "tshoo-tāng", "tian-tò-píng", "thòo-hueh", "thòo-huih", "khui-khuah", "luān-tshau-tshau", "puàn-suī", "sai-khia", "hó-khuànn-thâu", "bái-tsâi", "kìng-jiân", "kìng-liân", "bīn-thâu-tsîng", "suà-phah", "hó-tit", "tsí-iàu", "tshio-tiô", "tsia̍p-tsia̍p", "tuā-sì-kè", "tuā-sì-kuè", "sáng-sè", "tsiūnn-tshiú", "siōng-ke", "tsik-sî", "sūn-suà", "khó-pí", "pênn-pênn", "pînn-pînn", "tshing-khì-siùnn", "tshuah-lâu", "tī-tang-sî", "tú-tsiah", "muí-ji̍t", "muí-li̍t", "sù-siông", "tîng-puē", "tsū-ngóo", "thán-tshiò", "kha̍p-bē-tio̍h", "kha̍p-buē-tio̍h", "tīng-tauh", "ti̍t-ti̍t", "tsá-tsîng", "bián-kióng", "tshì-tsha̍k", "uî-lân", "khak-si̍t", "iōng-sim", "bô-tik-khak", "put-sî", "lí-kái", "phah-piànn", "pháinn-sí", "luán-jio̍k", "luán-lio̍k", "kui-kí", "kui-kú", "ná-tshiūnn", "khik-khui", "tīng-khok-khok", "uan-iunn", "ta̍k-pái", "suà-tshuì", "tshoo-tshoo", "kiat-si̍t", "nā-bô", "put-tik-liáu", "kó-jiân", "kó-liân", "iû-tsāi", "kau-tînn", "kan-kan-á", "luî-thuî", "sann-kap", "tsa̍p-tshài-mī", "nā-tsún", "thìng-hó", "it-ti̍t", "phòng-sai-sai", "thàu-bué", "thàu-bé", "tsi̍t-puànn", "tsi̍t-kuá-á", "tsuân-jiân", "tsuân-liân", "khang-thâu", "kang-hu", "lo̍h-lâi", "m̄ hó-sè", "ké-iánn", "tshiah-ia̍h", "nńg-tsiánn", "tshiâng-tsāi", "si̍p-tsuân", "siāng-khuán", "pún-tsiânn", "tang-sî", "tshim-khik", "ian-n̄g", "khi-khiau", "pe̍h-ba̍k", "khì-tò", "ua̍h-huē", "ua̍h-hē", "ti̍t-liu-liu", "kàu-pún", "kong-khui", "suî-sî", "thiau-kang", "tsiong-kî-bué", "tsiong-kî-bé", "pe̍h-pe̍h", "thán-ti̍t", "thian-tho̍h", "thàu-té", "thàu-tué", "pau-ún", "siông-sè", "siàu-liân", "tshóng-pōng", "pōo-pîn", "tsiànn-pān", "ngē-piàng-piàng", "ngī-piàng-piàng", "tham-tsâi", "thâu-bué", "thâu-bé", "hong-so", "bô-guā-kú", "sio-kāng", "pá-tsuí", "tshiú-kang", "liāu-siáu", "tsí-sī", "kuì-khì", "tsìng-king", "hó-tshuì", "ìnn-ònn", "tsū-thâu", "kai-tong", "pân-gî", "ua̍h-tāng", "pó-siú", "pún-lâi", "ua̍h-tsuí", "tuā-hàn", "ngē-tshah", "ngī-tshah", "hô-khóo", "tong-sî", "kàu-sî", "koo-khu̍t", "lī-king", "sí-lâng", "tshù-bī", "sin-khóo", "pháinn-khuànn", "siáu-siáu", "kìnn-bīn", "tshiú-tshìng", "tsi̍t-kuá", "kong-khai", "kiau-ngōo", "lâu-tsî", "it-lu̍t", "hiám-hiám", "hán-hán--á", "lóng-tsóng", "niā-niā", "bâ-pì", "kan-hiu", "tsiâu-ûn", "tshin-tshiūnn", "tshiánn-bān", "liâu-liâu-á", "tsó-iū", "kuè-āu", "kè-āu", "ing-kai-jiân", "ing-kai-liân", "tâng-tsê", "tsí-hó", "lán-si", "sio-tshuā", "bô-ì-tiong", "guā-guā", "hue-pa-li-niau", "kú-kú", "tshìn-tshái", "uá-nî", "āu-thâu", "tsa̍p-tsn̂g", "siong-tiōng", "ta̍uh-ta̍uh-á", "tshing-tsīng", "buē-tsîng-buē", "bē-tsîng-bē", "liân-suà", "ke-kiám", "tshun-ûn", "phùn-tiám", "bān-sìng", "kiōng-kiōng", "áng-láng", "bué--lâi", "bé--lâi", "kán-tan", "tsia̍h-tshī", "tàu-tah", "tsua̍t-tuì", "huí-luī", "ū-la̍t", "lân-bián", "kan-sîn", "tāi-hong", "ū-tang-sî-á", "senn-pún", "sinn-pún", "huann-hí", "līng-guā", "bo̍k-tsiân", "to̍k-to̍k", "tshân-tshân", "tshím-thâu", "sí-huē", "sí-hē", "khuah-bóng-bóng", "kiàn-nā", "ē-sái", "pe̍h-bah", "sí-tse̍h", "tik-khak", "lān-muā", "tshun-hong", "uì-kuânn", "liú-lia̍h", "tsiong-kīn", "tsiong-kūn", "khuah-tshuì", "thán-khi", "sin-sian", "ki̍k-ke", "tu̍t-jiân", "tu̍t-liân", "pit-jiân", "pit-liân", "uân-tsuân", "tshûn-sí", "tsi̍t-sì-kè", "tsi̍t-sì-kuè", "pat-tin", "pháinn-kiat-tiāu", "phái-kiat-tiāu", "bô-siau", "ta̍p-tih", "bué-tshiú", "bé-tshiú", "liân-sio̍k", "hit-tsūn", "hit-lō", "tsiânn-lâng", "í-tsîng", "kè-sio̍k", "iá-bī", "uè-suè", "è-sè", "khah-ke", "tuā-káng", "ku-ku-pih-pih", "kui-sim", "ū-sî-á", "ji̍t-āu", "li̍t-āu", "pháinn-tshiú-jiáu", "pháinn-tshiú-niáu", "tshoo-ióng", "kám-sī", "tshiâ-ba̍k", "thâu-thiànn", "tsuan-kang", "hán-tit", "uan-óng", "tsáu-tsông", "ngē-tsiānn", "ngī-tsiānn", "tsâi-tsîng", "kuè-tsuí", "kè-tsuí", "phóo-thong", "m̄-nā", "kan-khóo", "thiau-lāng", "hô-pit", "ē-pái", "kū-té", "kū-tué", "nńg-kô-kô", "ná-tshin-tshiūnn", "m̄-guān", "tong-tē", "tong-tuē", "hong-liû", "phú-phú", "it-lia̍p-it", "to̍k-tshâi", "guân-tsāi", "ū-tshun", "it-tīng", "tsiah-nī-á", "kiōng-beh", "kiōng-bueh", "láu-pâi", "tsia̍h-la̍t", "ū-tsîng", "khah-tsá", "kip-sìng", "huâinn-ti̍t", "huînn-ti̍t", "lio̍h-á", "uán-jiân", "uán-liân", "kik-kut", "sè-uī", "suè-uī", "tsiah-nī", "sūn-sè", "tiānn-tio̍h", "pîn-liông-sim", "phah-sǹg", "tsiū-án-ne", "pháinn-khang", "pháinn-sè", "kam-guān", "pháinn-bīn", "phái-bīn", "khó-lîng", "tsi̍t-ha̍k-sái", "lîm-sî", "iáu-m̄-koh", "kiám-tshái", "tshing-tshái", "buē-tsîng", "bē-tsîng", "bān-bān-á", "ji̍t-siông", "li̍t-siông", "li-li-lo-lo", "bîng-bîng", "tio̍h-sî", "tong-tiûnn", "tsīn-tiong", "iáu-siū", "tsiah-sī", "tsiânn-si̍t", "gû-pi", "siōng-kài", "ing-kai", "tsia̍h-hong", "líng-khì", "thóo-kong-á", "sè-hàn", "suè-hàn", "lo̍h-khì", "thâu-tú-á", "tuā-lōo", "sái-tháng", "oo-sian", "tàu-té", "tàu-tué", "sió-sòo", "tsi̍t-tiap-á-kú", "m̄-tú-hó", "tshenn-huan", "tshinn-huan", "siông-siông", "khuìnn-ua̍h", "kánn-sī", "tsá-àm", "bái-kâu", "kha-sau", "kàu-kang", "khuann-khuann-á", "thâu-khí-sing", "sóng-khuài", "thán-huâinn", "thán-huînn", "tàng-sng", "bān-it", "puànn-lōo", "it-khài", "tshit-thô", "bô-tiānn-tio̍h", "ná-thang", "tiām-tiām", "ē-tàng", "uan-uan-uat-uat", "tú-hó", "ló-tshó", "guân-pún", "ū-sî-tsūn", "tsìn-tsîng", "bān-tshiánn", "it-tàn", "khah-thîng-á", "thàu-lâu", "kiàn-pái", "tiau-tî", "puē-kut", "bô-khang", "hô-mí-khóo", "tsū-tsá", "huan-tiám", "thīn-thâu", "sìng-keh", "pháinn-tshuì-táu", "bô-kàu", "bān-bān", "líng-lī", "bô-îng", "tshio-ko", "kám-kóng", "bô-tshái", "sū-āu", "tò-píng", "thán-phak", "su-hā", "lām-sám", "tsiām-tshiánn", "khui-khiàm", "kong-tō", "tsì-tsió", "làu-sái-bé", "sian-tsìn", "bô-gî", "tē-it", "nńg-kut", "mi-mi-mauh-mauh", "ngē-tú-ngē", "ngī-tú-ngī", "tsū-iû", "tsài-sann", "hiān-hiān", "iáu-ū", "tú-tn̄g", "iū-koh", "bān-put-hīng", "tsiàu-siông", "kui-khì", "suà-tshiú", "lo-so", "piànn-miā", "bo̍k-hui", "phoo-pâi", "bē-tit", "buē-tit", "uan-khiau", "khòo-khòo", "tong-jiân", "tong-liân", "lo̍h-bué-tshiú", "lo̍h-bé-tshiú", "m̄-tsiânn-kâu", "iù-khí", "bô-lōo", "tuā-tsâng", "tuā-siann", "tú-teh", "m̄-ta̍t", "tuā-khoo", "khu-sok", "tsīn-li̍k", "luān-sú", "íng-uán", "kuè-hué", "kè-hé", "tng-bīn", "pa-kiat", "khiā-sǹg-kóng", "iáu-koh teh", "khang-tshuì-pōo-tsi̍h", "bâ-bui", "kik-sái", "sí-giān-giān", "m̄-tō", "bān-lîng", "tshiâng-tshiâng-kún", "ha̍p-kai", "bih-tshiu", "àm-bo̍k-bo̍k", "ông-lo̍k-á", "kuánn-kín", "ba̍k-ham", "kuè-ba̍k", "kè-ba̍k", "lím-lím--á", "m̄-bián", "huān-sè", "í-āu", "tsū-pún", "tsē-tsió", "tsuē-tsió", "sîng-jîn", "sîng-lîn", "ún-tàng", "senn-sîng", "sinn-sîng", "nńg-sìm-sìm", "guân-té", "guân-tué", "sua-sap", "bî-bî-á", "án-tsuánn", "sim-sik", "iōng-kong", "būn-būn", "kàu-bué", "kàu-bé", "làu-làu", "íng-íng", "thâu-ba̍k-tsiáu", "sio-jua̍h", "sio-lua̍h", "khóo-khóo", "kuann-liâu", "tò-thâu", "sè-jī", "suè-lī", "kú--lâi", "phah-sńg", "tshing-sim", "koo-láu", "bô-tiunn-tî", "kî-tiong", "hā-siau", "hiau-hīng", "suî-āu", "bē-hù-tshī", "buē-hù-tshī", "tūn-ba̍k", "síng-kang", "tsáu-thiàu", "làng-gue̍h", "làng-ge̍h", "tsá-nî", "lîng-khó", "tsìng-phài", "koh-khah", "iu-guân", "thong-siông", "tsū-té", "tsū-tué", "guân-tsuân", "ke-pô", "tah-tah", "huán-tsíng", "hiān-tú-hiān", "ta̍k-ji̍t", "ta̍k-li̍t", "tsiàu-khí-kang", "tsīn-liōng", "ū-sî", "iau-sò", "tsîng-kàu-tann", "khah-kóng", "tsi̍t-ē", "m̄-thang", "piau-tsún", "tshit-uànn-peh-uànn", "tshit-uànn-pueh-uànn", "āu-bué", "āu-bé", "khì-liáu-liáu", "tāi-sing", "síng-tsînn", "tuā-hīnn", "tuā-hī", "àu-sái", "tshenn-líng", "tshinn-líng", "hàm-kóo", "tîm-té", "tîm-tué", "lūn-tsin", "bī-bián", "lī-hāi", "iù-kut", "ē-īng-tit", "teh-beh", "teh-bueh", "iáu-buē", "iáu-bē", "m̄-kam", "hô-tsê", "hô-tsuê", "tī-sî", "káng-kiù", "uē-sing", "bô-ì-bô-sù", "tshian-bān", "tsì-guān", "bué-á", "bé-á", "siōng-thâu-á", "bô-gî-ngōo", "hó-pháinn", "ki̍p-sî", "put-kuán-sî", "iàu-kín", "bô-kio̍k", "tuā-tōo-kui", "kan-na", "kánn-ná", "án-ne-senn", "án-ní-sinn", "thán-tó", "tâu-ki", "khang-tshiú", "ua̍h-beh", "ua̍h-bueh", "ing-ia", "tng-teh", "táng-hiannh", "muá-ì", "tsha-put-to", "jîn-jîn-jîn", "lîn-lîn-lîn", "hē-sènn-miā", "hē-sìnn-miā", "sim-būn", "kuàn-tsuí", "mé-tshénn", "mé-tshínn", "sua-sua", "àng-tōo", "suî-piān", "gâu-tsá", "it-sing", "tsi̍t-bīn", "tāi-put-liáu", "hiah-nī", "tah-sim", "hó-khuànn", "āu--lâi", "bô-khuì", "tian-tò", "tsim-tsiok", "ū-tsi̍t-ji̍t", "ū-tsi̍t-li̍t", "hiah-nī-á", "hia--ê", "án-ne", "án-ni", "a̍h-tio̍h", "sè-kài", "pún-té", "pún-tué", "thài-pîng", "kui-tshing-bān", "káu-kuài", "thàu-mê", "thàu-mî", "thàn-tsá", "koo-put-jî-tsiong", "koo-put-lî-tsiong", "tshiāng-tú-tshiāng", "bûn-sin", "àu-kóo", "tshinn-tshioh", "liap-sái", "siōng-bô", "giám-ngē", "giám-ngī", "thau-thau-á", "liōng-kî-iok", "pún-thóo", "kuè-tōo", "kè-tōo", "sī-suā", "tsù-sí", "it--lâi", "thóo-huí", "thán-khiā", "hut-jiân", "hut-liân", "bîng-pi̍k", "kàu-kàu", "kāu-sua-sap", "khùn-lân", "tsiànn-bīn", "hiông-hiông", "tsiap-kha", "tú-tú", "kuí-nā kang", "kòo-tīng", "jû-tshú", "lû-tshú", "a̍h-sái", "suah-bué", "suah-bé", "iû-lâi", "sè-tāi", "îng-sin", "hó-sè", "kín-tsua̍h-bān", "kî-si̍t", "puànn-the-tó", "tsāi-sik--ê", "ti̍t-tsiap", "khò-sè", "kàu-tann", "sîng-si̍t", "tsuan-bûn", "kong-ke", "ba̍k-nih-á", "tshi-ko", "li̍k-sik", "tuā-pān", "pîng-siông", "thàu-tsá", "thâu--á", "hia̍p-li̍k", "ē-sái-tit", "tsiām-tsiām", "tiām-tsīng", "iáu-koh", "koh-tsài", "tshiau-kuè", "tshiau-kè", "kiâm-tok-tok", "tshut-thâu", "tiānn-tiānn", "siōng-kú", "phóo-phóo-á", "liâm-mi", "tinn-but-but", "tsiàu-si̍t", "é-káu", "giàn-thâu", "tiâu-ti̍t", "thiám-thâu", "hong-piān", "hó-hó-á", "àm-tiong", "thang-kng", "hó-sim", "tsóng-kiōng", "tshâ-ba̍k"
               ]