DT_ActionVerb = ["反輾轉",
                 "輾轉",
                 "提供",
                 "設計",
                 "欣賞",
                 "使用",
                 "來往",
                 "來臨",
                 "保存",
                 "保留",
                 "偷拈",
                 "偷聽",
                 "公佈",
                 "公演",
                 "冷凍",
                 "改變",
                 "改革",
                 "輕秤",
                 "咬岫",
                 "咬喙",
                 "變款",
                 "想欲",
                 "欲死",
                 "欲去",
                 "欲來",
                 "欲愛",
                 "啞口",
                 "喝枵",
                 "拋網",
                 "聯絡",
                 "著急",
                 "加捌",
                 "加入",
                 "加得",
                 "加添",
                 "加講話",
                 "受害",
                 "食食",
                 "懍場",
                 "吞忍",
                 "回絕",
                 "坐胎",
                 "外銷",
                 "內銷",
                 "守寡",
                 "就任",
                 "展伸",
                 "廢除",
                 "趕工",
                 "接跤",
                 "發燒",
                 "發酵",
                 "引起",
                 "起來",
                 "出來",
                 "出仕",
                 "出題",
                 "入來",
                 "害去",
                 "出去",
                 "傳出去",
                 "走出去",
                 "走袂離",
                 "走江湖",
                 "好食睏",
                 "燒好香",
                 "交落身",
                 "好離離",
                 "好離",
                 "離婚",
                 "出頭",
                 "出頭天",
                 "雨澹水滴",
                 "牽龜落湳",
                 "看破跤手",
                 "嫌東嫌西",
                 "看口得",
                 "看鬧熱",
                 "害人",
                 "唬人",
                 "罵人",
                 "享用",
                 "註冊",
                 "擺撥",
                 "滿意",
                 "報告",
                 "由在",
                 "嚇驚",
                 "摸飛",
                 "準備",
                 "放學",
                 "轉來",
                 "呷飯",
                 "食飯",
                 "表演",
                 "表現",
                 "放火",
                 "自首",
                 "耍歹",
                 "相見",
                 "餓死",
                 "難產",
                 "燒了了",
                 "主辦",
                 "止疼",
                 "熱著",
                 "分發",
                 "負擔",
                 "敬重",
                 "交纏",
                 "專門",
                 "慒心",
                 "衝過",
                 "受訓",
                 "食暗頓",
                 "曉",
                 "改薰",
                 "歹過日",
                 "打對折",
                 "揤牢",
                 "火大",
                 "出脫",
                 "倒數",
                 "比賽",
                 "充滿",
                 "完成",
                 "明呼",
                 "明唱",
                 "恭喜",
                 "體貼",
                 "情願",
                 "焦鍋",
                 "曝焦",
                 "收成",
                 "收入來",
                 "落種",
                 "參加",
                 "朗讀",
                 "讀冊",
                 "僫𤉙",
                 "落塗",
                 "落土",
                 "落軟",
                 "準煞",
                 "減講",
                 "代理",
                 "厚操煩",
                 "去了了",
                 "消災解厄",
                 "初見面",
                 "惜命命",
                 "枵過飢",
                 "倒轉來",
                 "趕轉去",
                 "準煞去",
                 "去倒害",
                 "吞吞吐吐",
                 "相挖空",
                 "大趁錢",
                 "大笑",
                 "大哭",
                 "培養",
                 "破去",
                 "過火",
                 "巴結",
                 "講出去",
                 "驚生份",
                 "驚一趒",
                 "關起來",
                 "出風頭",
                 "頓印仔",
                 "出國",
                 "保持",
                 "出在",
                 "拍結",
                 "拍算",
                 "拍拚",
                 "拍賣",
                 "拍電動",
                 "拍手",
                 "拍手蹄仔",
                 "楦闊",
                 "改進",
                 "展翼",
                 "決定",
                 "臭酸",
                 "落伍",
                 "好過",
                 "坐車",
                 "美容",
                 "收盤",
                 "頓落",
                 "迫倚",
                 "穿鞋",
                 "完工",
                 "割開",
                 "穿鞋仔",
                 "穿襪",
                 "穿襪仔",
                 "穿衫",
                 "歹行",
                 "歹勢",
                 "好得",
                 "走閃得",
                 "睏坦覆",
                 "分配",
                 "刣人",
                 "等於",
                 "確定",
                 "閃西風",
                 "賰",
                 "拄",
                 "拄天",
                 "突顯",
                 "燒熱",
                 "過來",
                 "相拍",
                 "支持",
                 "愛護",
                 "愛食",
                 "愛睏",
                 "愛著",
                 "借用",
                 "甘願",
                 "憂悶",
                 "艱苦",
                 "服務",
                 "疼惜",
                 "保重",
                 "調養",
                 "安搭",
                 "還錢",
                 "見笑",
                 "失志",
                 "憑良心",
                 "徛衛兵",
                 "梳妝打扮",
                 "寒人",
                 "熱人",
                 "寫批",
                 "分散",
                 "過日",
                 "過身",
                 "過日子",
                 "期待",
                 "振動",
                 "慶祝",
                 "恐驚",
                 "入門",
                 "破病",
                 "警告",
                 "說明",
                 "交陪",
                 "交接",
                 "做煞",
                 "牽著",
                 "設得",
                 "落肥",
                 "服從",
                 "期待",
                 "模仿",
                 "決算",
                 "決鬥",
                 "沐澹",
                 "淘汰",
                 "演出",
                 "火化",
                 "燒掉",
                 "犯煞",
                 "疲勞",
                 "盲從",
                 "相載",
                 "相隨",
                 "相剋",
                 "看見",
                 "看破",
                 "說破",
                 "點破",
                 "破費",
                 "禁止",
                 "紀念",
                 "贊成",
                 "空嘔",
                 "空襲",
                 "奮鬥",
                 "扣掉",
                 "走便所",
                 "嘔心血",
                 "施肥",
                 "感謝",
                 "延伸",
                 "忍耐",
                 "扣押",
                 "扣除",
                 "扶插",
                 "抽懸",
                 "抽稅",
                 "抽",
                 "拗斷",
                 "捋平",
                 "採用",
                 "提出",
                 "敲破",
                 "牽連",
                 "緊旋",
                 "繼承",
                 "罷免",
                 "義賣",
                 "要求",
                 "強求",
                 "誦經",
                 "超越",
                 "輸出",
                 "退出",
                 "退燒",
                 "過勞",
                 "過濾",
                 "過秤",
                 "遠足",
                 "理解",
                 "注意",
                 "遮光",
                 "替換",
                 "避免",
                 "還俗",
                 "鑑別",
                 "較講",
                 "當做",
                 "飛行",
                 "食紅",
                 "體諒",
                 "高攀",
                 "閃避",
                 "閃過",
                 "閃開",
                 "監督",
                 "熄火",
                 "掠狂",
                 "斟酌",
                 "見赴",
                 "蔫蔫去",
                 "滴落來",
                 "啾啾叫",
                 "講話",
                 "講究",
                 "在生",
                 "講東講西",
                 "記得",
                 "懇求",
                 "得罪",
                 "得著",
                 "值得",
                 "決落去",
                 "唔唔睏",
                 "留長長",
                 "摠規摠",
                 "扒龍船",
                 "拍通關",
                 "顧三頓",
                 "卸世眾",
                 "卸世卸眾",
                 "撙節",
                 "𣁳起來",
                 "摔落",
                 "違反",
                 "死了",
                 "養老",
                 "揣著",
                 "巡視",
                 "遵照",
                 "明知",
                 "弄獅",
                 "發現",
                 "摃破",
                 "得失",
                 "貪著",
                 "刺字",
                 "分魚",
                 "下蹛",
                 "稽考",
                 "阻止",
                 "挾死",
                 "食醋",
                 "煩死",
                 "合喙",
                 "合併",
                 "合唱",
                 "合作",
                 "寬限",
                 "回答",
                 "臭彈",
                 "相對相",
                 "深交",
                 "烏陰",
                 "應聲",
                 "枉死",
                 "頓著",
                 "準",
                 "鼓勵",
                 "鼓舞",
                 "跳舞",
                 "破鼎去",
                 "自殺",
                 "著痧",
                 "出現",
                 "落去",
                 "離開",
                 "開叉",
                 "開學",
                 "開破",
                 "開張",
                 "開放",
                 "開會",
                 "開車",
                 "開鎖",
                 "陷害",
                 "門試",
                 "類推",
                 "保庇",
                 "串通",
                 "伸冤",
                 "伸手",
                 "重句",
                 "戲弄",
                 "枉費",
                 "接載",
                 "趕路",
                 "照顧",
                 "感覺",
                 "規定",
                 "保護",
                 "賠錢",
                 "修養",
                 "修理",
                 "減輕",
                 "珍惜",
                 "畢業",
                 "挽掉",
                 "進步",
                 "拍破",
                 "拍斷",
                 "痴迷",
                 "哼哼呻",
                 "頭轉客",
                 "迷信",
                 "根據",
                 "落來",
                 "討厭",
                 "通報",
                 "敬予",
                 "執政",
                 "欠用",
                 "欠安",
                 "欠數",
                 "交往",
                 "入耳",
                 "串講",
                 "回頭",
                 "回覆",
                 "穢著",
                 "假做",
                 "氣死",
                 "僫講",
                 "硬拗",
                 "惱死",
                 "矮人",
                 "飛",
                 "按",
                 "載",
                 "過",
                 "澄清",
                 "送神",
                 "接神",
                 "報廢",
                 "汙染",
                 "污染",
                 "盡忠",
                 "分派",
                 "灇水",
                 "算會和",
                 "洗門風",
                 "拚暝工",
                 "算袂和",
                 "起衝突",
                 "送做堆",
                 "㧒擲捒",
                 "結綵帶",
                 "刁故意",
                 "照起工",
                 "恐驚見",
                 "著賊偷",
                 "食頭路",
                 "食碰釘",
                 "落空車",
                 "食牢",
                 "通過",
                 "通過關",
                 "洗汰",
                 "請假",
                 "減肥",
                 "心酸",
                 "汰",
                 "卸祖公",
                 "揈落去",
                 "娶入門",
                 "行酒家",
                 "斜過來",
                 "斜目",
                 "滲屎尿",
                 "幌韆鞦",
                 "相照顧",
                 "",
                 "懸",
                 "低",
                 "山",
                 "反來反去",
                 "跩來跩去",
                 "自作自專",
                 "興風作浪",
                 "魚肉鄉民",
                 "激一个氣",
                 "起跤動手",
                 "趒跤頓蹄",
                 "招兵買馬",
                 "想空想縫",
                 "烏青凝血",
                 "消瘦落肉",
                 "準拄煞",
                 "出日頭",
                 "浡出來",
                 "做出來",
                 "提出來",
                 "洩出來",
                 "放落來",
                 "相交插",
                 "做狗爬",
                 "講落去",
                 "講白賊話",
                 "磕袂著",
                 "裝痟的",
                 "激怐怐",
                 "倒踏蹬",
                 "呼倚來",
                 "塌落來",
                 "落落去",
                 "蟯蟯鑽",
                 "填落海",
                 "滿出來",
                 "喀喀嗽",
                 "鼻看嘜",
                 "鼻一下",
                 "摳摳叫",
                 "齁齁叫",
                 "鼾鼾叫",
                 "咂咂叫",
                 "窣窣叫",
                 "跋跋倒",
                 "激五仁",
                 "有準算",
                 "犯太歲",
                 "假死",
                 "過癮",
                 "辦理",
                 "膨風",
                 "膨起來",
                 "誣賴",
                 "拆散",
                 "服侍",
                 "擾亂",
                 "疊衫",
                 "認老",
                 "戀愛",
                 "貪戀",
                 "回批",
                 "自修",
                 "顧擔",
                 "顧人怨",
                 "塌底",
                 "吐血",
                 "臭屁",
                 "歹去",
                 "慼心",
                 "破功",
                 "拆破",
                 "消化",
                 "煏開",
                 "喘氣",
                 "憂愁",
                 "出勤",
                 "出錢",
                 "煩惱",
                 "戇想",
                 "醉酒",
                 "揀食",
                 "墜腸",
                 "計較",
                 "麻煩",
                 "提去",
                 "鎮位",
                 "光臨",
                 "塌空",
                 "保障",
                 "跤球",
                 "聯合",
                 "按算",
                 "留學",
                 "開始",
                 "相拄搪",
                 "硬拄硬",
                 "呷好料",
                 "食好料",
                 "喝酒醉",
                 "啉酒醉",
                 "睏落眠",
                 "搝後跤",
                 "會記得",
                 "搦屎搦尿",
                 "喘",
                 "踮",
                 "插",
                 "印",
                 "烘",
                 "黏",
                 "齪",
                 "替",
                 "摸",
                 "捽",
                 "拗",
                 "用",
                 "拖",
                 "拖累",
                 "害",
                 "改",
                 "坐",
                 "吐",
                 "吵",
                 "予",
                 "出",
                 "加",
                 "開",
                 "關",
                 "活",
                 "欲",
                 "落",
                 "驚",
                 "有",
                 "趁",
                 "攬",
                 "琢",
                 "糝",
                 "嗾",
                 "做",
                 "來",
                 "來去",
                 "萎去",
                 "去",
                 "去掉",
                 "掠",
                 "交",
                 "限",
                 "陷",
                 "響",
                 "領",
                 "願",
                 "錄",
                 "配",
                 "配合",
                 "滑倒",
                 "蹛",
                 "調",
                 "讀",
                 "變",
                 "蹺",
                 "造",
                 "運",
                 "裝",
                 "見",
                 "蓋",
                 "栽",
                 "求",
                 "沖",
                 "沿",
                 "泡",
                 "注",
                 "湧",
                 "煎",
                 "照",
                 "猜",
                 "畫",
                 "眠",
                 "知",
                 "示",
                 "祝",
                 "禁",
                 "租",
                 "種",
                 "穿",
                 "站",
                 "等",
                 "算",
                 "簽",
                 "約",
                 "約束",
                 "睏癖",
                 "捅出來",
                 "享受",
                 "相卸代",
                 "受傷",
                 "結",
                 "經",
                 "縫",
                 "考",
                 "考牢",
                 "聘",
                 "取",
                 "堆",
                 "塗",
                 "墜",
                 "夾",
                 "孵",
                 "射",
                 "巡",
                 "帶",
                 "幫",
                 "幹",
                 "度",
                 "弄",
                 "彈",
                 "念",
                 "怨",
                 "恨",
                 "愛",
                 "憑",
                 "懸",
                 "批",
                 "披",
                 "抿",
                 "拊",
                 "拍",
                 "拔",
                 "招",
                 "指",
                 "捻",
                 "排",
                 "搭",
                 "撇",
                 "擋",
                 "操",
                 "據",
                 "教",
                 "令",
                 "仿",
                 "伐",
                 "作",
                 "供",
                 "信",
                 "倒",
                 "傷",
                 "凍",
                 "剪",
                 "創",
                 "劃",
                 "劫",
                 "動",
                 "包",
                 "升",
                 "㧌",
                 "卡",
                 "食",
                 "飲",
                 "乞",
                 "牽",
                 "笑",
                 "痺",
                 "chai",
                 "lām",
                 "斷去",
                 "鼻著",
                 "恥笑",
                 "失業",
                 "電頭鬃",
                 "生出來",
                 "食外口",
                 "駛入去",
                 "拍交落去",
                 "抾起來",
                 "建設",
                 "做水災",
                 "代課",
                 "出入",
                 "比較",
                 "保證",
                 "近視",
                 "管教",
                 "論輩",
                 "食老",
                 "食歹",
                 "行踏",
                 "把握",
                 "操煩",
                 "老來",
                 "閣來",
                 "安搭",
                 "安養",
                 "分開",
                 "主張",
                 "妥協",
                 "賰錢",
                 "提簿",
                 "毋甘",
                 "磨鏡",
                 "會合",
                 "許配",
                 "處理",
                 "驅煞",
                 "貧血",
                 "強身",
                 "養性",
                 "出破",
                 "體會",
                 "後悔",
                 "中風",
                 "集倚",
                 "死會",
                 "平分",
                 "拍損",
                 "痠軟",
                 "搬有法",
                 "起酒痟",
                 "大細聲",
                 "捽目尾",
                 "上天堂",
                 "貿工程",
                 "現出來",
                 "挻挻年",
                 "縛跤縛手",
                 "tshì-giām", "tsng-thānn", "phùn-tiám", "lo̍k-tē", "bú-jio̍k", "bú-lio̍k", "síng-kang", "puàn-suī", "tah-tah", "kiông-tsè", "tsáu-im", "tap-tshuì-kóo", "tio̍h-tsióng", "tio̍h-tsiáng", "ut-áu", "lo-so", "tsí-hui", "iàu-kín", "khò-sè", "uan-ke", "tshâi-hông", "soo-io", "tàng-sng", "lo̍h-làm", "tsáu-tsua̍h", "kiânn-ta̍h", "si̍p-kuàn", "bûn-sin", "phah-sńg", "khàu-pē", "sái-ba̍k-tsìnn", "pàng-sak", "lâu-nuā", "tsia̍h-tê", "thâi-thâu", "bîng-pi̍k", "liān-siáu-uē", "tsih-tsiap", "ké-siáu", "pit-sûn", "siu-ióng", "nāu-tâi", "tāi-piáu", "tham-tsâi", "tiâu-pak", "sé-bīn", "sué-bīn", "giàng-gê", "khan-suànn", "pháinn-pháng", "phái-pháng", "tuā-siann", "kap-kóo", "sok-io", "piān-hōo", "kíng-kò", "tînn-tuè", "tînn-tè", "kuè-tōo", "kè-tōo", "khé-sī", "kha̍p-thâu", "ián-káng", "that-tshuì-khang", "tò-tuānn", "pó-tsìng", "piàn-siòng", "hué-sio-poo", "hé-sio-poo", "an-the̍h", "ūn-tōng", "tshuán-khuì", "pìnn-lāng", "ìn-uē", "jia-hong", "lia-hong", "thóng-kè", "tsok-gia̍p", "tshē-siàu", "tsuán-tsia̍h", "piànn-miā", "tsáu-su", "tiānn-tio̍h", "ji̍p-sim", "li̍p-sim", "suà-phah", "tōng-uân", "tū-tsuí", "thuah-mn̂g", "tiām-tiām", "tuì-tshuì", "kau-penn", "kau-pinn", "kám-kak", "bâ-tsuì", "ka-la̍uh", "tsiūnn-toh", "bo̍k-bo̍k-siû", "thong-ti", "kau-puê", "hioh-khùn", "tsīng-tsō", "tsú-ì", "thòo-liân-siân", "thàn-tsia̍h", "tsi-tshî", "pháu-bé", "hàu-kìng", "pìnn-kâu-lāng", "tshut-tshiú", "phah-kat-kiû", "uî-lân", "se̍h-thâu", "tah-hing-khám", "tiàu-ko", "î-bîn", "bán-kin", "bán-kun", "khiàm-khueh", "khiàm-kheh", "tàm-thâu", "sin-khóo", "kau-kuah", "kiat-kó", "kuè-óng", "kè-óng", "king-giām", "tiám-hia̍t", "khíng-tīng", "làng-káng", "tshiau-sing", "tsua̍t-lōo", "thàm-thiann", "tuā-hàn", "kenn-si", "kinn-si", "tiùnn-kuân-kè", "siu-suah", "uì-kuânn", "hó-tshuì", "khui-khiàm", "tshiah-hue", "tìn-tè", "sūn-hong", "tio̍h-kâu", "khioh-bah-iù-á", "ióng-tshī", "lo̍h-thôo", "huê-phue", "hê-phue", "teh-sàu", "kiông-kòng", "tsiânn-lâng", "sǹg-siàu", "tsò-thâu", "tsuè-thâu", "pûn-hong", "lī-iōng", "pàng-tshìng", "pa-kiat", "ē-tit-kuè", "ē-tit-kè", "kiám-tiám", "kuè-tshiú", "kè-tshiú", "kui-tīng", "tsiò-kiànn", "pàng-tshiú", "kuái-lōng", "tsàm-kha-pōo", "khuànn-ū", "puê-ióng", "siū-tsuē", "lô-tōng", "pí-jū", "pí-lū", "huan-gîng", "kik-sái", "phiàn-gín-á", "tshiûnn-hong", "kik-kut", "thīn-thâu", "bak-tshiú", "tńg-se̍h", "tsí-sī", "siōng-king", "thàng-hái", "phah-tshenn-kiann", "phah-tshinn-kiann", "tì-ì", "kiàn-siat", "khàu-tshan", "ūn-khì", "kin-suî", "kun-suî", "khui-tshuì", "tsē-uī", "siu-tsông", "tshut-lâi", "pàng-siàu", "tshiúnn-thâu-hiunn", "ngia̍uh-ngia̍uh-sô", "bô--khì", "thiah-phuà", "phah-tshiú", "kè-sǹg", "m̄-guān", "kau-tshap", "píng-pìnn", "ke-uē", "m̄-ta̍t", "tsiù-tshàm", "tsū-kak", "phu̍t-phu̍t-thiàu", "teh--lo̍h-khì", "thiu-tn̂g", "phah-ka-la̍uh", "hong-piān", "suah-bué", "suah-bé", "tông-ki", "tông-ku", "tó-siàu", "pàng-siann", "póo-phuà-bāng", "hau-siâu", "tiám-miâ", "la̍p-tsînn", "kuè-kè", "hūn-bê", "sing-ua̍h", "thiah-phiò", "khui-hue", "tánn-kik", "kin-tuè", "kun-tè", "uá-khò", "ùn tāu-iû", "tshu-phuē", "tshu-phē", "tshim-huān", "kàu-hùn", "thiah-khui", "khu-pia̍t", "siūnn-kóng", "khui-tsho", "thiu-thâu", "hua̍t-lo̍h", "sio-thīn", "bô-hē-lo̍h", "pau-ún", "gōo-huē", "khai-káng", "tsing-sîn", "kau-tsiap", "huan-i̍k", "kuè-lôo", "kè-lôo", "kái-tsong", "kuè-pōng", "kè-pōng", "--hngh", "tsù-siā", "tsáng-thâu", "kng-kiō", "pàng-phuì", "tshuā-thâu", "tîm-té", "tîm-tué", "lí-lūn", "phah-tn̄g", "pái-puah", "hām-bîn", "pàng-ba̍k", "khuànn-phuà", "tsō-huán", "tshiong-kong", "phuà-tiánn", "kau-hīnn", "kau-hī", "lâi-óng", "sîng-jîn", "sîng-lîn", "tsoh-sit", "tánn-tsah", "tsáu-tsông", "tsù-bo̍k", "tām-sám", "khuànn-māi", "hòng-sàng", "ta̍p-tih", "thiàu-tsuí", "tsia̍h-la̍t", "khioh-kíng", "kái-tap", "tāng-tshiú", "tú-tn̄g", "hū-tam", "phì-lūn-kóng", "bih-tshiu", "huan-hù", "tshûn-pān", "tik-sit", "kái-sàn", "tsia̍h-hong", "khiā-khí", "tshòng-tī", "hān-tsè", "ū-té", "ū-tué", "sio-tsing", "kài-siāu", "liam-hiunn", "tsáu-sio-jiok", "tsáu-sio-lip", "khí-pōng", "kiàn-tì", "hàinn-thâu", "tsia̍h-siann", "pài-hāu", "hun-huat", "huan-tsháu", "tò-tńg", "sáng-sè", "ua̍t-thâu", "tshut-thâu", "tò-áu", "e-bí", "sìn-iōng", "tsíng-ām", "su-iânn", "khan-tshiú", "tshut-sán", "tsìn-tsîng", "siat-sióng", "pí-phīng", "tiām--khì", "siu-hīng", "kuānn-tsuí", "khì-tò", "nih-ba̍k", "siu-lí", "tú-tio̍h", "kuàn-tsuí", "khui-to", "suánn-bē", "suánn-buē", "siat-kè", "phoo-pâi", "bīng-līng", "tsha̍k-ba̍k", "ti̍t-ba̍k", "thê-gī", "tsò-buê", "tsuè-buê", "khe-khó", "thê-khí", "tshàng-tshiu", "sio-khiàm-tsè", "an-uì", "hoo-tshiánn", "tsò-tshin-tsiânn", "tsuè-tshin-tsiânn", "lê-tshân", "huán-hîng", "tsih-la̍t", "thong-kuè", "thong-kè", "iah-khang", "lo̍h-tsûn", "ha̍p-sǹg", "óo-khang", "ué-khang", "siu-tiûnn", "làu-ē-hâi", "khuànn-thâu", "kuà-pâi", "khioh-gín-á", "huann-hí", "huê-thâu", "hê-thâu", "kóo-tong", "uí-jīm", "uí-līm", "tsóng-kuán", "kiàn-siàu", "su-tshut", "tháu-pàng", "tsù-tsheh", "lī-tshiú", "hû-tshî", "buah-bīn", "tshia-tó", "tsiap-tshiú", "liām-king", "phah-sǹg", "phòng-hong", "thiàu-bú", "phah-bē", "phah-buē", "tshit-thô", "tsè-koo", "hē-pún", "tshun-tshiú", "tsim-tsiok", "iô-lóo", "kòo-mê", "kòo-mî", "kong-khui", "sio-phah-tiān", "ta-sé", "ta-sué", "tsia̍h-miâ", "lí-kái", "kàu-io̍k", "kuè-tsuí", "kè-tsuí", "tsia̍h-tshài", "ua̍h-tāng", "ke-pô", "siàn-hong", "kau-tài", "au-kiâm-tshài", "pàng-hueh", "pàng-huih", "sing-sán", "bē-tú-hó", "buē-tú-hó", "pò-siau", "kuè-ba̍k", "kè-ba̍k", "huan-thâu", "tsia̍h-tàu", "puânn-tshuì-gím", "tha̍k-tsheh", "tsiūnn-tshiú", "ìn-siann", "ho̍k-sāi", "lîng-tî", "pian-tsi̍p", "pài-tn̂g", "tshiau-kuè", "tshiau-kè", "so-înn", "khan-gû", "ji̍p-mn̂g", "li̍p-mn̂g", "ngē-ah", "ngī-ah", "kiáu-jiáu", "kiáu-liáu", "tsiam-tsǹg", "huat-hiān", "sio-tú", "ngē-áu", "ngī-áu", "tsú-tiunn", "khiā-tâi", "kau-tînn", "hong-siann", "kik-sim", "suà-tshuì-bué", "suà-tshuì-bé", "siu-ji̍p", "siu-li̍p", "tshâi-kuat", "tńg-tshuì", "khui-tshī", "kiàn-gī", "pak-phuê", "pak-phê", "pàng-hún-tsiáu", "pâi-kái", "khui-bīn", "liap-kíng", "pháinn-sí", "huat-lián", "tio̍h-tak", "huan-sin", "âng-ba̍k", "khò-suann", "hì-lāng", "liù-phí-á", "kè-kàu", "iōng-sim", "thún-ta̍h", "siú-tsiat", "tàng-lōo-tsuí", "puann-hì", "tsún-tsò", "tsún-tsuè", "tāi-piān", "sim-būn", "khiā-miâ", "tshē-té", "tshē-tué", "thiàu-tsuā", "tsù-kái", "hōng-sàng", "inn-tînn", "uan-óng", "si̍t-giām", "lo̍h-lâi", "pó-siú", "tshut-kháu", "bô-îng", "kòng-kiû", "kuì-tsuá", "lo̍h-suann", "tiàu-kâu", "tsáu-pio", "tsiong-kun", "bô-tshái", "thè-sî", "thiu-kuân", "thio-hue-tshiah-siù", "tshíng-kiû", "hong-sîn", "tuì-siòng", "khui-tshia", "ho̍k-bū", "hong-tshuì", "pun-tsînn", "lâi-khì", "khai-gia̍p", "kià-thok", "kòo-tīng", "sio-sàng", "kong-khai", "tiàu-tōng", "tò-thè-lu", "thap-khang", "tsìng-bîng", "tso-gū", "khuànn-pēnn", "khuànn-pīnn", "king-kuè", "king-kè", "ta̍h-uē-thâu", "kiong-hí", "tīng-sìng", "siōng-khò", "bô-sè-jī", "bô-suè-lī", "sái-ba̍k-bué", "sái-ba̍k-bé", "pîng-kin", "pîng-kun", "tsia̍h-tsuē", "iáu-siū", "khuànn-bô", "tōng-pông", "su-thong", "tsù-sí", "lo̍h-tsuí", "kàu-tsuí", "suá-phoo", "kuánn-kín", "kuè-khì", "kè-khì", "tshiong-tu̍t", "phuānn-tshuā", "tsìn-thè", "tsō-lōo", "po̍k-lōo", "làu-hong", "lāng-hong", "kè-uē", "hong-so", "lo̍h-khì", "liáu-tsînn", "tò-tiàu", "muá-ì", "tsok-kuài", "tsau-that", "phò-kong", "khui-lōo", "khui-toh", "sin-tshíng", "soo-khai", "hòo-tsuí", "bé-phiò", "bué-phiò", "hāu-póo", "huat-tōng", "kái-kuat", "phah-hué", "phah-hé", "tuì-khuànn", "tshun-ûn", "kuè-nî", "kè-nî", "huê-hok", "hê-hok", "king-li̍k", "tsing-tsha", "káu-sua", "khi-khiau", "pik-tshik", "pik-tshiok", "sian-piànn-sian", "khui-bōo", "liap-sái", "bē-sin", "buē-sin", "tsiap-tshuì", "siau-tháu", "phah-phún", "kiânn-tshun", "khiau-kha", "siâ-sī", "huán-tsíng", "thòo-hueh", "thòo-huih", "thàm-thâu", "khiàm-īng", "kiám-tīng", "puah-kang", "tshut-ji̍p", "tshut-li̍p", "sí-tse̍h", "tio̍h-tse", "tshue-hong", "tshe-hong", "uè-suè", "è-sè", "khu-sok", "kā-tsi̍h", "tsi̍p--tsi̍t-ē", "kái-thuat", "phôo-thánn", "siông-sè", "lo̍h-tâi", "káng-kiù", "phòng-ting", "siu-sok", "tshia̍k-tshia̍k-tiô", "tshuán-tuā-khuì", "tsiânn-mi̍h", "tsiânn-mn̍gh", "uānn-tshiú", "ūn-tsuán", "tshe-kà", "tshut-khîn", "tshut-khûn", "lâu-thng", "liân-huê", "tàng-kah", "gián-kiù", "hàu-koo", "pāi-bé", "tsia̍h-jīn", "tsia̍h-līn", "su-ji̍p", "su-li̍p", "sian-ti", "lak-tshat", "tiâu-ti̍t", "sioh-phuê", "sioh-phê", "tsáu-thiàu", "tshit-kha-tshng", "sún-sit", "ìng-iōng", "se̍h-lin-long", "khòng-bah", "thê-thâu", "tòng-gōng"
             ]