DT_FuncDegreeHead = ["遮爾",
                     "閣較",
                     "如此",
                     "非常",
                     "遐爾仔",
                     "遐爾",
                     "愈",
                     "tng-tih",
                     "khah"
                     ]